==> haskell-data-default-instances-containers-0.0.1-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-containers
version:              0.0.1
visibility:           public
id:
    data-default-instances-containers-0.0.1-Lcmo3oTDUcoLRSJDGZmCzD

key:
    data-default-instances-containers-0.0.1-Lcmo3oTDUcoLRSJDGZmCzD

license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in containers
category:             Data
abi:                  b66cce7df7c91ee53a92180c128bfec9
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-8.10.4/site-local/data-default-instances-containers-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/data-default-instances-containers-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/data-default-instances-containers-0.0.1

hs-libraries:
    HSdata-default-instances-containers-0.0.1-Lcmo3oTDUcoLRSJDGZmCzD

depends:
    base-4.14.1.0 containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-containers-0.0.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-default-instances-containers
version:              0.0.1
visibility:           public
id:
    data-default-instances-containers-0.0.1-Cus4UskkH8p1sssZ2pjaqd

key:
    data-default-instances-containers-0.0.1-Cus4UskkH8p1sssZ2pjaqd

license:              BSD-3-Clause
maintainer:           <l.mai@web.de>
author:               Lukas Mai
synopsis:             Default instances for types in containers
category:             Data
abi:                  dcbff972b7bc7ce4c96877ee9add4854
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/data-default-instances-containers-0.0.1

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/data-default-instances-containers-0.0.1

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/data-default-instances-containers-0.0.1

hs-libraries:
    HSdata-default-instances-containers-0.0.1-Cus4UskkH8p1sssZ2pjaqd

depends:
    base-4.14.2.0 containers-0.6.4.1
    data-default-class-0.1.2.0-9cFfQKP7sucLLfD3ZZyiPI

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
